==> gitlab-18.5.2-1-x86_64.pkg.tar.zst: usr/share/webapps/gitlab/.gitlab/issue_templates/Plan - Spike.md <==
<!--The purpose of this spike template is to ensure that the teams have all the information they need before approaching a spike. Teams across product, engineering and design should collaborate to ensure the feature tackled in the spike is thought through and that all necessary details are included.

This template is not a set-in-stone prerequisite for spikes as some of the spikes are more abstract. So this template is designed to be customizable and fit the majority of the use cases.-->

## Proposal

### What is the goal of this spike?

`{ Add a description about the feature and why we are implementing it. Leave as many details as known/necessary. }`

### Scope/MVC

- _What features are considered GA and non-GA and how do they look like/function?  What are the absolute must have fetures we want from this PSike and what would be an add-on? A checklist might be beneficial to include._
- _Any known blockers/dependancies (not necessarily from a technical perspective). Are there other moving parts or spikes related to this one? In which capacity are they related?_

### Designs :frame_photo:

_Links to designs, they can be WIP. Please note that this refernce should be the absoulte source of truth for designs. Any other information can be put here related to the designs._

## Roadmap / Time estimates

_This section is for product to include any relevant links to roadmaps and general timelines with respect to the project in question and related/blocking spikes. This section can also be used by engineers to roughly determine when do we want to deliver the outcomes after the spike is done. Timelines are never set in stone, but this can be a good pointer for everyone._

## Open questions

_Any other related unknowns or information deemed useful for the spike. This can include assumptions that need validation or any other questions that need general verification._


<!--The template is stored at `.gitlab/issue_templates/Plan - Spike.md` directory if you need to update it -->

==> gitlab-18.6.0-1-x86_64.pkg.tar.zst: usr/share/webapps/gitlab/.gitlab/issue_templates/Plan - Spike.md <==
<!--The purpose of this spike template is to ensure that the teams have all the information they need before approaching a spike. Teams across product, engineering and design should collaborate to ensure the feature tackled in the spike is thought through and that all necessary details are included.

This template is not a set-in-stone prerequisite for spikes as some of the spikes are more abstract. So this template is designed to be customizable and fit the majority of the use cases.-->

## Proposal

### What is the goal of this spike?

`{ Add a description about the feature and why we are implementing it. Leave as many details as known/necessary. }`

### Scope/MVC

- _What features are considered GA and non-GA and how do they look like/function? What are the absolute must have features we want from this PSike and what would be an add-on? A checklist might be beneficial to include._
- _Any known blockers/dependencies (not necessarily from a technical perspective). Are there other moving parts or spikes related to this one? In which capacity are they related?_

### Designs :frame_photo:

_Links to designs, they can be WIP. Please note that this reference should be the absolute source of truth for designs. Any other information can be put here related to the designs._

## Roadmap / Time estimates

_This section is for product to include any relevant links to roadmaps and general timelines with respect to the project in question and related/blocking spikes. This section can also be used by engineers to roughly determine when do we want to deliver the outcomes after the spike is done. Timelines are never set in stone, but this can be a good pointer for everyone._

## Open questions

_Any other related unknowns or information deemed useful for the spike. This can include assumptions that need validation or any other questions that need general verification._

<!--The template is stored at `.gitlab/issue_templates/Plan - Spike.md` directory if you need to update it -->
